@@ -68,7 +68,7 @@ abstract class PluginManagerBase implements PluginManagerInterface {
   /**
    * {@inheritdoc}
    */
-  public function createInstance($plugin_id, array $configuration = array()) {
+  public function createInstance($plugin_id, array $configuration = []) {
     // If this PluginManager has fallback capabilities catch
     // PluginNotFoundExceptions.
     if ($this instanceof FallbackPluginManagerInterface) {
@@ -76,8 +76,7 @@ abstract class PluginManagerBase implements PluginManagerInterface {
         return $this->getFactory()->createInstance($plugin_id, $configuration);
       }
       catch (PluginNotFoundException $e) {
-        $fallback_id = $this->getFallbackPluginId($plugin_id, $configuration);
-        return $this->getFactory()->createInstance($fallback_id, $configuration);
+        return $this->handlePluginNotFound($plugin_id, $configuration);
       }
     }
     else {
@@ -85,6 +84,22 @@ abstract class PluginManagerBase implements PluginManagerInterface {
     }
   }
 
+  /**
+   * Allows plugin managers to specify custom behavior if a plugin is not found.
+   *
+   * @param string $plugin_id
+   *   The ID of the missing requested plugin.
+   * @param array $configuration
+   *   An array of configuration relevant to the plugin instance.
+   *
+   * @return object
+   *   A fallback plugin instance.
+   */
+  protected function handlePluginNotFound($plugin_id, array $configuration) {
+    $fallback_id = $this->getFallbackPluginId($plugin_id, $configuration);
+    return $this->getFactory()->createInstance($fallback_id, $configuration);
+  }
+
   /**
    * {@inheritdoc}
    */
