@@ -26,7 +26,7 @@ class ConfigSchemaDiscovery implements DiscoveryInterface {
    * @param $schema_storage
    *   The storage object to use for reading schema data.
    */
-  function __construct(StorageInterface $schema_storage) {
+  public function __construct(StorageInterface $schema_storage) {
     $this->schemaStorage = $schema_storage;
   }
 
@@ -34,7 +34,7 @@ class ConfigSchemaDiscovery implements DiscoveryInterface {
    * {@inheritdoc}
    */
   public function getDefinitions() {
-    $definitions = array();
+    $definitions = [];
     foreach ($this->schemaStorage->readMultiple($this->schemaStorage->listAll()) as $schema) {
       foreach ($schema as $type => $definition) {
         $definitions[$type] = $definition;
