@@ -149,6 +149,13 @@ class BaseFieldOverride extends FieldConfigBase {
     return $this->getBaseFieldDefinition()->getClass();
   }
 
+  /**
+   * {@inheritdoc}
+   */
+  public function getUniqueIdentifier() {
+    return $this->getBaseFieldDefinition()->getUniqueIdentifier();
+  }
+
   /**
    * Gets the base field definition.
    *
