@@ -778,9 +778,9 @@ class FormBuilder implements FormBuilderInterface, FormValidatorInterface, FormS
           '#attached' => [
             'placeholders' => [
               $placeholder => [
-                '#lazy_builder' => ['form_builder:renderFormTokenPlaceholder', [$placeholder]]
-              ]
-            ]
+                '#lazy_builder' => ['form_builder:renderFormTokenPlaceholder', [$placeholder]],
+              ],
+            ],
           ],
           '#cache' => [
             'max-age' => 0,
