@@ -22,10 +22,19 @@ class AccountProxy implements AccountProxyInterface {
    */
   protected $account;
 
+  /**
+   * Account id.
+   *
+   * @var int
+   */
+  protected $id = 0;
+
   /**
    * Initial account id.
    *
    * @var int
+   *
+   * @deprecated Scheduled for removal in Drupal 8.4.x. Use $this->id instead.
    */
   protected $initialAccountId;
 
@@ -39,6 +48,7 @@ class AccountProxy implements AccountProxyInterface {
       $account = $account->getAccount();
     }
     $this->account = $account;
+    $this->id = $account->id();
     date_default_timezone_set(drupal_get_user_timezone());
   }
 
@@ -47,11 +57,11 @@ class AccountProxy implements AccountProxyInterface {
    */
   public function getAccount() {
     if (!isset($this->account)) {
-      if ($this->initialAccountId) {
+      if ($this->id) {
         // After the container is rebuilt, DrupalKernel sets the initial
         // account to the id of the logged in user. This is necessary in order
         // to refresh the user account reference here.
-        $this->setAccount($this->loadUserEntity($this->initialAccountId));
+        $this->setAccount($this->loadUserEntity($this->id));
       }
       else {
         $this->account = new AnonymousUserSession();
@@ -65,7 +75,7 @@ class AccountProxy implements AccountProxyInterface {
    * {@inheritdoc}
    */
   public function id() {
-    return $this->getAccount()->id();
+    return $this->id;
   }
 
   /**
@@ -160,7 +170,7 @@ class AccountProxy implements AccountProxyInterface {
       throw new \LogicException('AccountProxyInterface::setInitialAccountId() cannot be called after an account was set on the AccountProxy');
     }
 
-    $this->initialAccountId = $account_id;
+    $this->id = $this->initialAccountId = $account_id;
   }
 
   /**
