@@ -67,7 +67,7 @@ trait StringTranslationTrait {
    *
    * @ingroup sanitization
    */
-  protected function t($string, array $args = array(), array $options = array()) {
+  protected function t($string, array $args = [], array $options = []) {
     return new TranslatableMarkup($string, $args, $options, $this->getStringTranslation());
   }
 
@@ -76,7 +76,7 @@ trait StringTranslationTrait {
    *
    * @see \Drupal\Core\StringTranslation\TranslationInterface::formatPlural()
    */
-  protected function formatPlural($count, $singular, $plural, array $args = array(), array $options = array()) {
+  protected function formatPlural($count, $singular, $plural, array $args = [], array $options = []) {
     return new PluralTranslatableMarkup($count, $singular, $plural, $args, $options, $this->getStringTranslation());
   }
 
