@@ -16,7 +16,7 @@ class FeedStorage extends SqlContentEntityStorage implements FeedStorageInterfac
    * {@inheritdoc}
    */
   public function getFeedIdsToRefresh() {
-    return $this->database->query('SELECT fid FROM {aggregator_feed} WHERE queued = 0 AND checked + refresh < :time AND refresh <> :never', [
+    return $this->database->query('SELECT fid FROM {' . $this->getBaseTable() . '} WHERE queued = 0 AND checked + refresh < :time AND refresh <> :never', [
       ':time' => REQUEST_TIME,
       ':never' => AGGREGATOR_CLEAR_NEVER,
     ])->fetchCol();
