@@ -2,7 +2,7 @@
 
 namespace Drupal\basic_auth\Authentication\Provider;
 
-use Drupal\Component\Utility\SafeMarkup;
+use Drupal\Component\Render\FormattableMarkup;
 use Drupal\Core\Authentication\AuthenticationProviderInterface;
 use Drupal\Core\Authentication\AuthenticationProviderChallengeInterface;
 use Drupal\Core\Cache\CacheableMetadata;
@@ -129,7 +129,7 @@ class BasicAuth implements AuthenticationProviderInterface, AuthenticationProvid
   public function challengeException(Request $request, \Exception $previous) {
     $site_config = $this->configFactory->get('system.site');
     $site_name = $site_config->get('name');
-    $challenge = SafeMarkup::format('Basic realm="@realm"', [
+    $challenge = new FormattableMarkup('Basic realm="@realm"', [
       '@realm' => !empty($site_name) ? $site_name : 'Access restricted',
     ]);
 
