@@ -1,19 +1,21 @@
 <?php
 
-/**
- * @file
- * Contains \Drupal\config\Tests\AssertConfigEntityImportTrait.
- */
-
 namespace Drupal\config\Tests;
 
+@trigger_error('The ' . __NAMESPACE__ . '\AssertConfigEntityImportTrait is deprecated in Drupal 8.4.1 and will be removed before Drupal 9.0.0. Instead, use \Drupal\Tests\config\Traits\AssertConfigEntityImportTrait. See https://www.drupal.org/node/2916197.', E_USER_DEPRECATED);
+
 use Drupal\Core\Config\Entity\ConfigEntityInterface;
 
 /**
  * Provides test assertions for testing config entity synchronization.
  *
  * Can be used by test classes that extend \Drupal\simpletest\WebTestBase or
- * \Drupal\simpletest\KernelTestBase.
+ * \Drupal\KernelTests\KernelTestBase.
+ *
+ * @deprecated in Drupal 8.4.1 and will be removed before Drupal 9.0.0.
+ *   Use \Drupal\Tests\config\Traits\AssertConfigEntityImportTrait.
+ *
+ * @see https://www.drupal.org/node/2916197
  */
 trait AssertConfigEntityImportTrait {
 
