@@ -44,7 +44,7 @@ class ConfigFieldMapper extends ConfigEntityMapper {
    */
   public function getTypeLabel() {
     $base_entity_info = $this->entityManager->getDefinition($this->pluginDefinition['base_entity_type']);
-    return $this->t('@label fields', array('@label' => $base_entity_info->getLabel()));
+    return $this->t('@label fields', ['@label' => $base_entity_info->getLabel()]);
   }
 
   /**
