@@ -3,8 +3,9 @@
  * Attaches behaviors for the Contextual module.
  */
 
-(function ($, Drupal, drupalSettings, _, Backbone, JSON, storage) {
-  const options = $.extend(drupalSettings.contextual,
+(function($, Drupal, drupalSettings, _, Backbone, JSON, storage) {
+  const options = $.extend(
+    drupalSettings.contextual,
     // Merge strings on top of drupalSettings so that they are not mutable.
     {
       strings: {
@@ -16,79 +17,23 @@
 
   // Clear the cached contextual links whenever the current user's set of
   // permissions changes.
-  const cachedPermissionsHash = storage.getItem('Drupal.contextual.permissionsHash');
+  const cachedPermissionsHash = storage.getItem(
+    'Drupal.contextual.permissionsHash',
+  );
   const permissionsHash = drupalSettings.user.permissionsHash;
   if (cachedPermissionsHash !== permissionsHash) {
     if (typeof permissionsHash === 'string') {
-      _.chain(storage).keys().each((key) => {
-        if (key.substring(0, 18) === 'Drupal.contextual.') {
-          storage.removeItem(key);
-        }
-      });
+      _.chain(storage)
+        .keys()
+        .each(key => {
+          if (key.substring(0, 18) === 'Drupal.contextual.') {
+            storage.removeItem(key);
+          }
+        });
     }
     storage.setItem('Drupal.contextual.permissionsHash', permissionsHash);
   }
 
-  /**
-   * Initializes a contextual link: updates its DOM, sets up model and views.
-   *
-   * @param {jQuery} $contextual
-   *   A contextual links placeholder DOM element, containing the actual
-   *   contextual links as rendered by the server.
-   * @param {string} html
-   *   The server-side rendered HTML for this contextual link.
-   */
-  function initContextual($contextual, html) {
-    const $region = $contextual.closest('.contextual-region');
-    const contextual = Drupal.contextual;
-
-    $contextual
-      // Update the placeholder to contain its rendered contextual links.
-      .html(html)
-      // Use the placeholder as a wrapper with a specific class to provide
-      // positioning and behavior attachment context.
-      .addClass('contextual')
-      // Ensure a trigger element exists before the actual contextual links.
-      .prepend(Drupal.theme('contextualTrigger'));
-
-    // Set the destination parameter on each of the contextual links.
-    const destination = `destination=${Drupal.encodePath(drupalSettings.path.currentPath)}`;
-    $contextual.find('.contextual-links a').each(function () {
-      const url = this.getAttribute('href');
-      const glue = (url.indexOf('?') === -1) ? '?' : '&';
-      this.setAttribute('href', url + glue + destination);
-    });
-
-    // Create a model and the appropriate views.
-    const model = new contextual.StateModel({
-      title: $region.find('h2').eq(0).text().trim(),
-    });
-    const viewOptions = $.extend({ el: $contextual, model }, options);
-    contextual.views.push({
-      visual: new contextual.VisualView(viewOptions),
-      aural: new contextual.AuralView(viewOptions),
-      keyboard: new contextual.KeyboardView(viewOptions),
-    });
-    contextual.regionViews.push(new contextual.RegionView(
-      $.extend({ el: $region, model }, options)),
-    );
-
-    // Add the model to the collection. This must happen after the views have
-    // been associated with it, otherwise collection change event handlers can't
-    // trigger the model change event handler in its views.
-    contextual.collection.add(model);
-
-    // Let other JavaScript react to the adding of a new contextual link.
-    $(document).trigger('drupalContextualLinkAdded', {
-      $el: $contextual,
-      $region,
-      model,
-    });
-
-    // Fix visual collisions between contextual link triggers.
-    adjustIfNestedAndOverlapping($contextual);
-  }
-
   /**
    * Determines if a contextual link is nested & overlapping, if so: adjusts it.
    *
@@ -101,7 +46,8 @@
   function adjustIfNestedAndOverlapping($contextual) {
     const $contextuals = $contextual
       // @todo confirm that .closest() is not sufficient
-      .parents('.contextual-region').eq(-1)
+      .parents('.contextual-region')
+      .eq(-1)
       .find('.contextual');
 
     // Early-return when there's no nesting.
@@ -129,6 +75,72 @@
     }
   }
 
+  /**
+   * Initializes a contextual link: updates its DOM, sets up model and views.
+   *
+   * @param {jQuery} $contextual
+   *   A contextual links placeholder DOM element, containing the actual
+   *   contextual links as rendered by the server.
+   * @param {string} html
+   *   The server-side rendered HTML for this contextual link.
+   */
+  function initContextual($contextual, html) {
+    const $region = $contextual.closest('.contextual-region');
+    const contextual = Drupal.contextual;
+
+    $contextual
+      // Update the placeholder to contain its rendered contextual links.
+      .html(html)
+      // Use the placeholder as a wrapper with a specific class to provide
+      // positioning and behavior attachment context.
+      .addClass('contextual')
+      // Ensure a trigger element exists before the actual contextual links.
+      .prepend(Drupal.theme('contextualTrigger'));
+
+    // Set the destination parameter on each of the contextual links.
+    const destination = `destination=${Drupal.encodePath(
+      drupalSettings.path.currentPath,
+    )}`;
+    $contextual.find('.contextual-links a').each(function() {
+      const url = this.getAttribute('href');
+      const glue = url.indexOf('?') === -1 ? '?' : '&';
+      this.setAttribute('href', url + glue + destination);
+    });
+
+    // Create a model and the appropriate views.
+    const model = new contextual.StateModel({
+      title: $region
+        .find('h2')
+        .eq(0)
+        .text()
+        .trim(),
+    });
+    const viewOptions = $.extend({ el: $contextual, model }, options);
+    contextual.views.push({
+      visual: new contextual.VisualView(viewOptions),
+      aural: new contextual.AuralView(viewOptions),
+      keyboard: new contextual.KeyboardView(viewOptions),
+    });
+    contextual.regionViews.push(
+      new contextual.RegionView($.extend({ el: $region, model }, options)),
+    );
+
+    // Add the model to the collection. This must happen after the views have
+    // been associated with it, otherwise collection change event handlers can't
+    // trigger the model change event handler in its views.
+    contextual.collection.add(model);
+
+    // Let other JavaScript react to the adding of a new contextual link.
+    $(document).trigger('drupalContextualLinkAdded', {
+      $el: $contextual,
+      $region,
+      model,
+    });
+
+    // Fix visual collisions between contextual link triggers.
+    adjustIfNestedAndOverlapping($contextual);
+  }
+
   /**
    * Attaches outline behavior for regions associated with contextual links.
    *
@@ -146,19 +158,21 @@
       const $context = $(context);
 
       // Find all contextual links placeholders, if any.
-      let $placeholders = $context.find('[data-contextual-id]').once('contextual-render');
+      let $placeholders = $context
+        .find('[data-contextual-id]')
+        .once('contextual-render');
       if ($placeholders.length === 0) {
         return;
       }
 
       // Collect the IDs for all contextual links placeholders.
       const ids = [];
-      $placeholders.each(function () {
+      $placeholders.each(function() {
         ids.push($(this).attr('data-contextual-id'));
       });
 
       // Update all contextual links placeholders whose HTML is cached.
-      const uncachedIDs = _.filter(ids, (contextualID) => {
+      const uncachedIDs = _.filter(ids, contextualID => {
         const html = storage.getItem(`Drupal.contextual.${contextualID}`);
         if (html && html.length) {
           // Initialize after the current execution cycle, to make the AJAX
@@ -167,7 +181,10 @@
           // the chance to set up an event listener on the Backbone collection
           // Drupal.contextual.collection.
           window.setTimeout(() => {
-            initContextual($context.find(`[data-contextual-id="${contextualID}"]`), html);
+            initContextual(
+              $context.find(`[data-contextual-id="${contextualID}"]`),
+              html,
+            );
           });
           return false;
         }
@@ -195,7 +212,9 @@
                 // possible for multiple identical placeholders exist on the
                 // page (probably because the same content appears more than
                 // once).
-                $placeholders = $context.find(`[data-contextual-id="${contextualID}"]`);
+                $placeholders = $context.find(
+                  `[data-contextual-id="${contextualID}"]`,
+                );
 
                 // Initialize the contextual links.
                 for (let i = 0; i < $placeholders.length; i++) {
@@ -215,7 +234,6 @@
    * @namespace
    */
   Drupal.contextual = {
-
     /**
      * The {@link Drupal.contextual.View} instances associated with each list
      * element of contextual links.
@@ -238,7 +256,9 @@
    *
    * @type {Backbone.Collection}
    */
-  Drupal.contextual.collection = new Backbone.Collection([], { model: Drupal.contextual.StateModel });
+  Drupal.contextual.collection = new Backbone.Collection([], {
+    model: Drupal.contextual.StateModel,
+  });
 
   /**
    * A trigger is an interactive element often bound to a click handler.
@@ -246,7 +266,7 @@
    * @return {string}
    *   A string representing a DOM fragment.
    */
-  Drupal.theme.contextualTrigger = function () {
+  Drupal.theme.contextualTrigger = function() {
     return '<button class="trigger visually-hidden focusable" type="button"></button>';
   };
 
@@ -263,4 +283,12 @@
   $(document).on('drupalContextualLinkAdded', (event, data) => {
     Drupal.ajax.bindAjaxLinks(data.$el[0]);
   });
-}(jQuery, Drupal, drupalSettings, _, Backbone, window.JSON, window.sessionStorage));
+})(
+  jQuery,
+  Drupal,
+  drupalSettings,
+  _,
+  Backbone,
+  window.JSON,
+  window.sessionStorage,
+);
