@@ -5,7 +5,6 @@ namespace Drupal\Tests\field\Kernel\EntityReference;
 use Drupal\comment\Entity\Comment;
 use Drupal\comment\Entity\CommentType;
 use Drupal\Component\Render\FormattableMarkup;
-use Drupal\Component\Utility\Unicode;
 use Drupal\Core\Field\FieldItemListInterface;
 use Drupal\Core\Field\FieldItemInterface;
 use Drupal\Core\Field\FieldStorageDefinitionInterface;
@@ -80,7 +79,7 @@ class EntityReferenceItemTest extends FieldKernelTestBase {
 
     $this->vocabulary = Vocabulary::create([
       'name' => $this->randomMachineName(),
-      'vid' => Unicode::strtolower($this->randomMachineName()),
+      'vid' => mb_strtolower($this->randomMachineName()),
       'langcode' => LanguageInterface::LANGCODE_NOT_SPECIFIED,
     ]);
     $this->vocabulary->save();
@@ -283,7 +282,7 @@ class EntityReferenceItemTest extends FieldKernelTestBase {
     // Make sure the computed term reflects updates to the term id.
     $vocabulary2 = $vocabulary = Vocabulary::create([
       'name' => $this->randomMachineName(),
-      'vid' => Unicode::strtolower($this->randomMachineName()),
+      'vid' => mb_strtolower($this->randomMachineName()),
       'langcode' => LanguageInterface::LANGCODE_NOT_SPECIFIED,
     ]);
     $vocabulary2->save();
@@ -354,13 +353,13 @@ class EntityReferenceItemTest extends FieldKernelTestBase {
    * Tests that the 'handler' field setting stores the proper plugin ID.
    */
   public function testSelectionHandlerSettings() {
-    $field_name = Unicode::strtolower($this->randomMachineName());
+    $field_name = mb_strtolower($this->randomMachineName());
     $field_storage = FieldStorageConfig::create([
       'field_name' => $field_name,
       'entity_type' => 'entity_test',
       'type' => 'entity_reference',
       'settings' => [
-        'target_type' => 'entity_test'
+        'target_type' => 'entity_test',
       ],
     ]);
     $field_storage->save();
@@ -452,7 +451,7 @@ class EntityReferenceItemTest extends FieldKernelTestBase {
     $this->assertEqual($errors[0]->getPropertyPath(), 'field_test_node.0.entity');
 
     // Publish the node and try again.
-    $node->setPublished(TRUE);
+    $node->setPublished();
     $errors = $entity->validate();
     $this->assertEqual(0, count($errors));
 
@@ -502,7 +501,7 @@ class EntityReferenceItemTest extends FieldKernelTestBase {
     $this->assertEqual($errors[1]->getPropertyPath(), 'field_test_node.1.target_id');
 
     // Publish one of the nodes and try again.
-    $saved_unpublished_node->setPublished(TRUE);
+    $saved_unpublished_node->setPublished();
     $saved_unpublished_node->save();
     $errors = $entity->validate();
     $this->assertEqual(1, count($errors));
@@ -510,7 +509,7 @@ class EntityReferenceItemTest extends FieldKernelTestBase {
     $this->assertEqual($errors[0]->getPropertyPath(), 'field_test_node.0.entity');
 
     // Publish the last invalid node and try again.
-    $unsaved_unpublished_node->setPublished(TRUE);
+    $unsaved_unpublished_node->setPublished();
     $errors = $entity->validate();
     $this->assertEqual(0, count($errors));
 
@@ -534,7 +533,7 @@ class EntityReferenceItemTest extends FieldKernelTestBase {
     $this->assertEqual($errors[0]->getPropertyPath(), 'field_test_comment.0.entity');
 
     // Publish the comment and try again.
-    $comment->setPublished(TRUE);
+    $comment->setPublished();
     $errors = $entity->validate();
     $this->assertEqual(0, count($errors));
 
