@@ -12,6 +12,24 @@ use Drupal\Tests\migrate_drupal_ui\Functional\MigrateUpgradeReviewPageTestBase;
  */
 class MigrateUpgrade7ReviewPageTest extends MigrateUpgradeReviewPageTestBase {
 
+  /**
+   * {@inheritdoc}
+   */
+  public static $modules = [
+    'language',
+    'content_translation',
+    'telephone',
+    'aggregator',
+    'book',
+    'forum',
+    'statistics',
+    'syslog',
+    'tracker',
+    'update',
+    // Required for translation migrations.
+    'migrate_drupal_multilingual',
+  ];
+
   /**
    * {@inheritdoc}
    */
@@ -41,7 +59,6 @@ class MigrateUpgrade7ReviewPageTest extends MigrateUpgradeReviewPageTestBase {
       'date',
       'dblog',
       'email',
-      'entity_translation',
       'field',
       'field_sql_storage',
       'file',
@@ -59,6 +76,7 @@ class MigrateUpgrade7ReviewPageTest extends MigrateUpgradeReviewPageTestBase {
       'path',
       'phone',
       'profile',
+      'rdf',
       'search',
       'shortcut',
       'statistics',
@@ -92,6 +110,7 @@ class MigrateUpgrade7ReviewPageTest extends MigrateUpgradeReviewPageTestBase {
       'entity_feature',
       'entity_token',
       'entityreference',
+      'entity_translation',
       'field_ui',
       'help',
       'openid',
@@ -105,6 +124,7 @@ class MigrateUpgrade7ReviewPageTest extends MigrateUpgradeReviewPageTestBase {
       'simpletest',
       'stylizer',
       'term_depth',
+      'title',
       'toolbar',
       'translation',
       'trigger',
@@ -118,7 +138,6 @@ class MigrateUpgrade7ReviewPageTest extends MigrateUpgradeReviewPageTestBase {
    */
   protected function getMissingPaths() {
     return [
-      'rdf',
       'views',
     ];
   }
