@@ -31,6 +31,8 @@ class MigrateUpgrade7Test extends MigrateUpgradeExecuteTestBase {
     'forum',
     'statistics',
     'migration_provider_test',
+    // Required for translation migrations.
+    'migrate_drupal_multilingual',
   ];
 
   /**
@@ -58,16 +60,17 @@ class MigrateUpgrade7Test extends MigrateUpgradeExecuteTestBase {
       'block' => 25,
       'block_content' => 1,
       'block_content_type' => 1,
-      'comment' => 1,
+      'comment' => 2,
       // The 'standard' profile provides the 'comment' comment type, and the
       // migration creates 6 comment types, one per node type.
       'comment_type' => 7,
-      // Module 'language' comes with 'en', 'und', 'zxx'. Migration adds 'is'.
-      'configurable_language' => 4,
+      // Module 'language' comes with 'en', 'und', 'zxx'. Migration adds 'is'
+      // and 'fr'.
+      'configurable_language' => 5,
       'contact_form' => 3,
       'editor' => 2,
-      'field_config' => 66,
-      'field_storage_config' => 49,
+      'field_config' => 67,
+      'field_storage_config' => 50,
       'file' => 3,
       'filter_format' => 7,
       'image_style' => 6,
@@ -75,7 +78,7 @@ class MigrateUpgrade7Test extends MigrateUpgradeExecuteTestBase {
       'migration' => 73,
       'node' => 5,
       'node_type' => 6,
-      'rdf_mapping' => 7,
+      'rdf_mapping' => 8,
       'search_page' => 2,
       'shortcut' => 6,
       'shortcut_set' => 2,
@@ -103,7 +106,7 @@ class MigrateUpgrade7Test extends MigrateUpgradeExecuteTestBase {
   protected function getEntityCountsIncremental() {
     $counts = $this->getEntityCounts();
     $counts['block_content'] = 2;
-    $counts['comment'] = 2;
+    $counts['comment'] = 3;
     $counts['file'] = 4;
     $counts['menu_link_content'] = 13;
     $counts['node'] = 6;
@@ -127,7 +130,6 @@ class MigrateUpgrade7Test extends MigrateUpgradeExecuteTestBase {
       'dblog',
       'email',
       'entityreference',
-      'entity_translation',
       'field',
       'field_sql_storage',
       'file',
@@ -144,6 +146,7 @@ class MigrateUpgrade7Test extends MigrateUpgradeExecuteTestBase {
       'options',
       'path',
       'phone',
+      'rdf',
       'search',
       'shortcut',
       'statistics',
@@ -173,7 +176,6 @@ class MigrateUpgrade7Test extends MigrateUpgradeExecuteTestBase {
    */
   protected function getMissingPaths() {
     return [
-      'rdf',
       // These modules are in the missing path list because they are installed
       // on the source site but they are not installed on the destination site.
       'syslog',
