@@ -4,7 +4,6 @@ namespace Drupal\node\Tests;
 
 use Drupal\comment\Tests\CommentTestTrait;
 use Drupal\Core\Field\FieldStorageDefinitionInterface;
-use Drupal\Component\Utility\Unicode;
 use Drupal\Core\Language\LanguageInterface;
 use Drupal\Core\Url;
 use Drupal\field\Tests\EntityReference\EntityReferenceTestTrait;
@@ -88,7 +87,7 @@ class PagePreviewTest extends NodeTestBase {
     $field_config->save();
 
     // Create a field.
-    $this->fieldName = Unicode::strtolower($this->randomMachineName());
+    $this->fieldName = mb_strtolower($this->randomMachineName());
     $handler_settings = [
       'target_bundles' => [
         $this->vocabulary->id() => $this->vocabulary->id(),
@@ -134,7 +133,7 @@ class PagePreviewTest extends NodeTestBase {
       'type' => 'text',
       'settings' => [
         'max_length' => 50,
-      ]
+      ],
     ]);
     $field_storage->save();
     FieldConfig::create([
@@ -184,6 +183,10 @@ class PagePreviewTest extends NodeTestBase {
     $this->assertText($edit[$term_key], 'Term displayed.');
     $this->assertLink(t('Back to content editing'));
 
+    // Check that we see the class of the node type on the body element.
+    $body_class_element = $this->xpath("//body[contains(@class, 'page-node-type-page')]");
+    $this->assertTrue(!empty($body_class_element), 'Node type body class found.');
+
     // Get the UUID.
     $url = parse_url($this->getUrl());
     $paths = explode('/', $url['path']);
