@@ -89,7 +89,7 @@ class PathItem extends FieldItemBase {
    */
   public static function generateSampleValue(FieldDefinitionInterface $field_definition) {
     $random = new Random();
-    $values['alias'] = str_replace(' ', '-', strtolower($random->sentences(3)));
+    $values['alias'] = '/' . str_replace(' ', '-', strtolower($random->sentences(3)));
     return $values;
   }
 
