@@ -1,6 +1,9 @@
 <?php
 
 namespace Drupal\test_page_test\Controller;
+
+use Drupal\Core\Url;
+use Symfony\Component\HttpFoundation\RedirectResponse;
 use Symfony\Component\HttpKernel\Exception\HttpException;
 
 /**
@@ -12,7 +15,8 @@ class Test {
    * Renders a page with a title.
    *
    * @return array
-   *   A render array as expected by drupal_render()
+   *   A render array as expected by
+   *   \Drupal\Core\Render\RendererInterface::render().
    */
   public function renderTitle() {
     $build = [];
@@ -26,7 +30,8 @@ class Test {
    * Renders a page.
    *
    * @return array
-   *   A render array as expected by drupal_render().
+   *   A render array as expected by
+   *   \Drupal\Core\Render\RendererInterface::render().
    */
   public function staticTitle() {
     $build = [];
@@ -63,7 +68,8 @@ class Test {
    * Returns a generic page render array for title tests.
    *
    * @return array
-   *   A render array as expected by drupal_render()
+   *   A render array as expected by
+   *   \Drupal\Core\Render\RendererInterface::render().
    */
   public function renderPage() {
     return [
@@ -92,7 +98,8 @@ class Test {
    * Renders a page with encoded markup.
    *
    * @return array
-   *   A render array as expected by drupal_render()
+   *   A render array as expected by
+   *   \Drupal\Core\Render\RendererInterface::render().
    */
   public function renderEncodedMarkup() {
     return ['#plain_text' => 'Bad html <script>alert(123);</script>'];
@@ -102,10 +109,23 @@ class Test {
    * Renders a page with pipe character in link test.
    *
    * @return array
-   *   A render array as expected by drupal_render()
+   *   A render array as expected by
+   *   \Drupal\Core\Render\RendererInterface::render().
    */
   public function renderPipeInLink() {
     return ['#markup' => '<a href="http://example.com">foo|bar|baz</a>'];
   }
 
+  /**
+   * Loads a page that does a redirect.
+   *
+   * Drupal uses Symfony's RedirectResponse for generating redirects. That class
+   * uses a lower-case 'http-equiv="refresh"'.
+   *
+   * @see \Symfony\Component\HttpFoundation\RedirectResponse
+   */
+  public function metaRefresh() {
+    return new RedirectResponse(Url::fromRoute('test_page_test.test_page', [], ['absolute' => TRUE])->toString(), 302);
+  }
+
 }
