@@ -22,7 +22,7 @@ class DependencyMissingTest extends BrowserTestBase {
     // Only install update_test_2.module, even though its updates have a
     // dependency on update_test_3.module.
     parent::setUp();
-    require_once \Drupal::root() . '/core/includes/update.inc';
+    require_once $this->root . '/core/includes/update.inc';
   }
 
   public function testMissingUpdate() {
